diff --git a/django/db/backends/base/schema.py b/django/db/backends/base/schema.py
index 85caec688d..2a2c441f04 100644
--- a/django/db/backends/base/schema.py
+++ b/django/db/backends/base/schema.py
@@ -300,7 +300,7 @@ class BaseDatabaseSchemaEditor:
         # Prevent using [] as params, in the case a literal '%' is used in the definition
         self.execute(sql, params or None)
 
-        # Add any field index and index_together's (deferred as SQLite3 _remake_table needs it)
+        # Add any field index and index_together's (deferred as SQLite _remake_table needs it)
         self.deferred_sql.extend(self._model_indexes_sql(model))
 
         # Make M2M tables
diff --git a/django/db/backends/sqlite3/base.py b/django/db/backends/sqlite3/base.py
index 02c2a9c0c9..5d8f4028c2 100644
--- a/django/db/backends/sqlite3/base.py
+++ b/django/db/backends/sqlite3/base.py
@@ -1,5 +1,5 @@
 """
-SQLite3 backend for the sqlite3 module in the standard library.
+SQLite backend for the sqlite3 module in the standard library.
 """
 import datetime
 import decimal
diff --git a/django/db/backends/sqlite3/schema.py b/django/db/backends/sqlite3/schema.py
index 3992d86651..edc128fca2 100644
--- a/django/db/backends/sqlite3/schema.py
+++ b/django/db/backends/sqlite3/schema.py
@@ -24,7 +24,7 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
                 'SQLite schema editor cannot be used while foreign key '
                 'constraint checks are enabled. Make sure to disable them '
                 'before entering a transaction.atomic() context because '
-                'SQLite3 does not support disabling them in the middle of '
+                'SQLite does not support disabling them in the middle of '
                 'a multi-statement transaction.'
             )
         return super().__enter__()
diff --git a/tests/backends/sqlite/tests.py b/tests/backends/sqlite/tests.py
index c5b9569eac..d8efdf2821 100644
--- a/tests/backends/sqlite/tests.py
+++ b/tests/backends/sqlite/tests.py
@@ -91,7 +91,7 @@ class SchemaTests(TransactionTestCase):
             'SQLite schema editor cannot be used while foreign key '
             'constraint checks are enabled. Make sure to disable them '
             'before entering a transaction.atomic() context because '
-            'SQLite3 does not support disabling them in the middle of '
+            'SQLite does not support disabling them in the middle of '
             'a multi-statement transaction.'
         )
         with self.assertRaisesMessage(NotSupportedError, msg):
@@ -100,7 +100,7 @@ class SchemaTests(TransactionTestCase):
 
     def test_constraint_checks_disabled_atomic_allowed(self):
         """
         SQLite3 schema editor is usable within an outer transaction as long as
         foreign key constraints checks are disabled beforehand.
         """
         def constraint_checks_enabled():
@@ -100,7 +100,7 @@ class SchemaTests(TransactionTestCase):
     def test_constraint_checks_disabled_atomic_allowed(self):
         """
-        SQLite3 schema editor is usable within an outer transaction as long as
+        SQLite schema editor is usable within an outer transaction as long as
         foreign key constraints checks are disabled beforehand.
         """